@@ -3,7 +3,7 @@ package MOP4Import::Declare;
 use 5.010;
 use strict;
 use warnings qw(FATAL all NONFATAL misc);
-our $VERSION = '0.000_001';
+our $VERSION = '0.000_002';
 use Carp;
 use mro qw/c3/;
 
@@ -224,6 +224,10 @@ sub declare___add_isa {
       my $adding = mro::get_linear_isa($parent);
       eval {
 	unshift @$isa, $parent;
+	# if ($] < 5.014) {
+	#   mro::method_changed_in($objpkg);
+	#   mro::get_linear_isa($objpkg);
+	# }
       };
       if ($@) {
         croak "Can't add base '$parent' to '$objpkg' (\n"
@@ -277,7 +281,9 @@ sub declare_fields {
   foreach my $super_class (@{*{globref($opts->{objpkg}, 'ISA')}{ARRAY}}) {
     my $super = fields_hash($super_class);
     next unless $super;
-    foreach my $name (keys %$super) {
+    my $super_names = fields_array($super_class);
+    my @names = @$super_names ? @$super_names : keys %$super;
+    foreach my $name (@names) {
       next if defined $extended->{$name};
       print STDERR "  Field $opts->{objpkg}.$name is inherited "
 	. "from $super_class.\n" if DEBUG;
@@ -730,10 +736,6 @@ But you can extend FieldSpec in your exporter like following:
 
 KOBAYASHI, Hiroaki E<lt>hkoba@cpan.orgE<gt>
 
-=head1 SEE ALSO
-
-L<MOP4Import>, L<MOP4Import::Types>, L<MOP4Import::PSGIEnv>
-
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
